from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Numerics
import win32more.Windows.Perception
import win32more.Windows.Perception.People
import win32more.Windows.Perception.Spatial
import win32more.Windows.UI.Input
import win32more.Windows.UI.Input.Spatial
import win32more.Windows.Win32.System.WinRT
class EyesPose(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Perception.People.IEyesPose
    _classid_ = 'Windows.Perception.People.EyesPose'
    @winrt_mixinmethod
    def get_IsCalibrationValid(self: win32more.Windows.Perception.People.IEyesPose) -> Boolean: ...
    @winrt_mixinmethod
    def get_Gaze(self: win32more.Windows.Perception.People.IEyesPose) -> win32more.Windows.Foundation.IReference[win32more.Windows.Perception.Spatial.SpatialRay]: ...
    @winrt_mixinmethod
    def get_UpdateTimestamp(self: win32more.Windows.Perception.People.IEyesPose) -> win32more.Windows.Perception.PerceptionTimestamp: ...
    @winrt_classmethod
    def IsSupported(cls: win32more.Windows.Perception.People.IEyesPoseStatics) -> Boolean: ...
    @winrt_classmethod
    def RequestAccessAsync(cls: win32more.Windows.Perception.People.IEyesPoseStatics) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.UI.Input.GazeInputAccessStatus]: ...
    Gaze = property(get_Gaze, None)
    IsCalibrationValid = property(get_IsCalibrationValid, None)
    UpdateTimestamp = property(get_UpdateTimestamp, None)
class HandJointKind(Enum, Int32):
    Palm = 0
    Wrist = 1
    ThumbMetacarpal = 2
    ThumbProximal = 3
    ThumbDistal = 4
    ThumbTip = 5
    IndexMetacarpal = 6
    IndexProximal = 7
    IndexIntermediate = 8
    IndexDistal = 9
    IndexTip = 10
    MiddleMetacarpal = 11
    MiddleProximal = 12
    MiddleIntermediate = 13
    MiddleDistal = 14
    MiddleTip = 15
    RingMetacarpal = 16
    RingProximal = 17
    RingIntermediate = 18
    RingDistal = 19
    RingTip = 20
    LittleMetacarpal = 21
    LittleProximal = 22
    LittleIntermediate = 23
    LittleDistal = 24
    LittleTip = 25
class HandMeshObserver(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Perception.People.IHandMeshObserver
    _classid_ = 'Windows.Perception.People.HandMeshObserver'
    @winrt_mixinmethod
    def get_Source(self: win32more.Windows.Perception.People.IHandMeshObserver) -> win32more.Windows.UI.Input.Spatial.SpatialInteractionSource: ...
    @winrt_mixinmethod
    def get_TriangleIndexCount(self: win32more.Windows.Perception.People.IHandMeshObserver) -> UInt32: ...
    @winrt_mixinmethod
    def get_VertexCount(self: win32more.Windows.Perception.People.IHandMeshObserver) -> UInt32: ...
    @winrt_mixinmethod
    def GetTriangleIndices(self: win32more.Windows.Perception.People.IHandMeshObserver, indices: FillArray[UInt16]) -> Void: ...
    @winrt_mixinmethod
    def GetVertexStateForPose(self: win32more.Windows.Perception.People.IHandMeshObserver, handPose: win32more.Windows.Perception.People.HandPose) -> win32more.Windows.Perception.People.HandMeshVertexState: ...
    @winrt_mixinmethod
    def get_NeutralPose(self: win32more.Windows.Perception.People.IHandMeshObserver) -> win32more.Windows.Perception.People.HandPose: ...
    @winrt_mixinmethod
    def get_NeutralPoseVersion(self: win32more.Windows.Perception.People.IHandMeshObserver) -> Int32: ...
    @winrt_mixinmethod
    def get_ModelId(self: win32more.Windows.Perception.People.IHandMeshObserver) -> Int32: ...
    ModelId = property(get_ModelId, None)
    NeutralPose = property(get_NeutralPose, None)
    NeutralPoseVersion = property(get_NeutralPoseVersion, None)
    Source = property(get_Source, None)
    TriangleIndexCount = property(get_TriangleIndexCount, None)
    VertexCount = property(get_VertexCount, None)
class HandMeshVertex(Structure):
    Position: win32more.Windows.Foundation.Numerics.Vector3
    Normal: win32more.Windows.Foundation.Numerics.Vector3
class HandMeshVertexState(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Perception.People.IHandMeshVertexState
    _classid_ = 'Windows.Perception.People.HandMeshVertexState'
    @winrt_mixinmethod
    def get_CoordinateSystem(self: win32more.Windows.Perception.People.IHandMeshVertexState) -> win32more.Windows.Perception.Spatial.SpatialCoordinateSystem: ...
    @winrt_mixinmethod
    def GetVertices(self: win32more.Windows.Perception.People.IHandMeshVertexState, vertices: FillArray[win32more.Windows.Perception.People.HandMeshVertex]) -> Void: ...
    @winrt_mixinmethod
    def get_UpdateTimestamp(self: win32more.Windows.Perception.People.IHandMeshVertexState) -> win32more.Windows.Perception.PerceptionTimestamp: ...
    CoordinateSystem = property(get_CoordinateSystem, None)
    UpdateTimestamp = property(get_UpdateTimestamp, None)
class HandPose(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Perception.People.IHandPose
    _classid_ = 'Windows.Perception.People.HandPose'
    @winrt_mixinmethod
    def TryGetJoint(self: win32more.Windows.Perception.People.IHandPose, coordinateSystem: win32more.Windows.Perception.Spatial.SpatialCoordinateSystem, joint: win32more.Windows.Perception.People.HandJointKind, jointPose: POINTER(win32more.Windows.Perception.People.JointPose)) -> Boolean: ...
    @winrt_mixinmethod
    def TryGetJoints(self: win32more.Windows.Perception.People.IHandPose, coordinateSystem: win32more.Windows.Perception.Spatial.SpatialCoordinateSystem, joints: PassArray[win32more.Windows.Perception.People.HandJointKind], jointPoses: FillArray[win32more.Windows.Perception.People.JointPose]) -> Boolean: ...
    @winrt_mixinmethod
    def GetRelativeJoint(self: win32more.Windows.Perception.People.IHandPose, joint: win32more.Windows.Perception.People.HandJointKind, referenceJoint: win32more.Windows.Perception.People.HandJointKind) -> win32more.Windows.Perception.People.JointPose: ...
    @winrt_mixinmethod
    def GetRelativeJoints(self: win32more.Windows.Perception.People.IHandPose, joints: PassArray[win32more.Windows.Perception.People.HandJointKind], referenceJoints: PassArray[win32more.Windows.Perception.People.HandJointKind], jointPoses: FillArray[win32more.Windows.Perception.People.JointPose]) -> Void: ...
class HeadPose(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Perception.People.IHeadPose
    _classid_ = 'Windows.Perception.People.HeadPose'
    @winrt_mixinmethod
    def get_Position(self: win32more.Windows.Perception.People.IHeadPose) -> win32more.Windows.Foundation.Numerics.Vector3: ...
    @winrt_mixinmethod
    def get_ForwardDirection(self: win32more.Windows.Perception.People.IHeadPose) -> win32more.Windows.Foundation.Numerics.Vector3: ...
    @winrt_mixinmethod
    def get_UpDirection(self: win32more.Windows.Perception.People.IHeadPose) -> win32more.Windows.Foundation.Numerics.Vector3: ...
    ForwardDirection = property(get_ForwardDirection, None)
    Position = property(get_Position, None)
    UpDirection = property(get_UpDirection, None)
class IEyesPose(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Perception.People.IEyesPose'
    _iid_ = Guid('{682a9b23-8a1e-5b86-a060-906ffacb62a4}')
    @winrt_commethod(6)
    def get_IsCalibrationValid(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_Gaze(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Perception.Spatial.SpatialRay]: ...
    @winrt_commethod(8)
    def get_UpdateTimestamp(self) -> win32more.Windows.Perception.PerceptionTimestamp: ...
    Gaze = property(get_Gaze, None)
    IsCalibrationValid = property(get_IsCalibrationValid, None)
    UpdateTimestamp = property(get_UpdateTimestamp, None)
class IEyesPoseStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Perception.People.IEyesPoseStatics'
    _iid_ = Guid('{1cff7413-b21f-54c0-80c1-e60d994ca58c}')
    @winrt_commethod(6)
    def IsSupported(self) -> Boolean: ...
    @winrt_commethod(7)
    def RequestAccessAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.UI.Input.GazeInputAccessStatus]: ...
class IHandMeshObserver(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Perception.People.IHandMeshObserver'
    _iid_ = Guid('{85ae30cb-6fc3-55c4-a7b4-29e33896ca69}')
    @winrt_commethod(6)
    def get_Source(self) -> win32more.Windows.UI.Input.Spatial.SpatialInteractionSource: ...
    @winrt_commethod(7)
    def get_TriangleIndexCount(self) -> UInt32: ...
    @winrt_commethod(8)
    def get_VertexCount(self) -> UInt32: ...
    @winrt_commethod(9)
    def GetTriangleIndices(self, indices: FillArray[UInt16]) -> Void: ...
    @winrt_commethod(10)
    def GetVertexStateForPose(self, handPose: win32more.Windows.Perception.People.HandPose) -> win32more.Windows.Perception.People.HandMeshVertexState: ...
    @winrt_commethod(11)
    def get_NeutralPose(self) -> win32more.Windows.Perception.People.HandPose: ...
    @winrt_commethod(12)
    def get_NeutralPoseVersion(self) -> Int32: ...
    @winrt_commethod(13)
    def get_ModelId(self) -> Int32: ...
    ModelId = property(get_ModelId, None)
    NeutralPose = property(get_NeutralPose, None)
    NeutralPoseVersion = property(get_NeutralPoseVersion, None)
    Source = property(get_Source, None)
    TriangleIndexCount = property(get_TriangleIndexCount, None)
    VertexCount = property(get_VertexCount, None)
class IHandMeshVertexState(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Perception.People.IHandMeshVertexState'
    _iid_ = Guid('{046c5fef-1d8b-55de-ab2c-1cd424886d8f}')
    @winrt_commethod(6)
    def get_CoordinateSystem(self) -> win32more.Windows.Perception.Spatial.SpatialCoordinateSystem: ...
    @winrt_commethod(7)
    def GetVertices(self, vertices: FillArray[win32more.Windows.Perception.People.HandMeshVertex]) -> Void: ...
    @winrt_commethod(8)
    def get_UpdateTimestamp(self) -> win32more.Windows.Perception.PerceptionTimestamp: ...
    CoordinateSystem = property(get_CoordinateSystem, None)
    UpdateTimestamp = property(get_UpdateTimestamp, None)
class IHandPose(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Perception.People.IHandPose'
    _iid_ = Guid('{4d98e79a-bb08-5d09-91de-df0dd3fae46c}')
    @winrt_commethod(6)
    def TryGetJoint(self, coordinateSystem: win32more.Windows.Perception.Spatial.SpatialCoordinateSystem, joint: win32more.Windows.Perception.People.HandJointKind, jointPose: POINTER(win32more.Windows.Perception.People.JointPose)) -> Boolean: ...
    @winrt_commethod(7)
    def TryGetJoints(self, coordinateSystem: win32more.Windows.Perception.Spatial.SpatialCoordinateSystem, joints: PassArray[win32more.Windows.Perception.People.HandJointKind], jointPoses: FillArray[win32more.Windows.Perception.People.JointPose]) -> Boolean: ...
    @winrt_commethod(8)
    def GetRelativeJoint(self, joint: win32more.Windows.Perception.People.HandJointKind, referenceJoint: win32more.Windows.Perception.People.HandJointKind) -> win32more.Windows.Perception.People.JointPose: ...
    @winrt_commethod(9)
    def GetRelativeJoints(self, joints: PassArray[win32more.Windows.Perception.People.HandJointKind], referenceJoints: PassArray[win32more.Windows.Perception.People.HandJointKind], jointPoses: FillArray[win32more.Windows.Perception.People.JointPose]) -> Void: ...
class IHeadPose(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Perception.People.IHeadPose'
    _iid_ = Guid('{7f5ac5a5-49db-379f-9429-32a2faf34fa6}')
    @winrt_commethod(6)
    def get_Position(self) -> win32more.Windows.Foundation.Numerics.Vector3: ...
    @winrt_commethod(7)
    def get_ForwardDirection(self) -> win32more.Windows.Foundation.Numerics.Vector3: ...
    @winrt_commethod(8)
    def get_UpDirection(self) -> win32more.Windows.Foundation.Numerics.Vector3: ...
    ForwardDirection = property(get_ForwardDirection, None)
    Position = property(get_Position, None)
    UpDirection = property(get_UpDirection, None)
class JointPose(Structure):
    Orientation: win32more.Windows.Foundation.Numerics.Quaternion
    Position: win32more.Windows.Foundation.Numerics.Vector3
    Radius: Single
    Accuracy: win32more.Windows.Perception.People.JointPoseAccuracy
class JointPoseAccuracy(Enum, Int32):
    High = 0
    Approximate = 1


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.ApplicationModel.Resources.Management
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Win32.System.WinRT
class IIndexedResourceCandidate(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Resources.Management.IIndexedResourceCandidate'
    _iid_ = Guid('{0e619ef3-faec-4414-a9d7-54acd5953f29}')
    @winrt_commethod(6)
    def get_Type(self) -> win32more.Windows.ApplicationModel.Resources.Management.IndexedResourceType: ...
    @winrt_commethod(7)
    def get_Uri(self) -> win32more.Windows.Foundation.Uri: ...
    @winrt_commethod(8)
    def get_Metadata(self) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, WinRT_String]: ...
    @winrt_commethod(9)
    def get_Qualifiers(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Resources.Management.IndexedResourceQualifier]: ...
    @winrt_commethod(10)
    def get_ValueAsString(self) -> WinRT_String: ...
    @winrt_commethod(11)
    def GetQualifierValue(self, qualifierName: WinRT_String) -> WinRT_String: ...
    Metadata = property(get_Metadata, None)
    Qualifiers = property(get_Qualifiers, None)
    Type = property(get_Type, None)
    Uri = property(get_Uri, None)
    ValueAsString = property(get_ValueAsString, None)
class IIndexedResourceQualifier(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Resources.Management.IIndexedResourceQualifier'
    _iid_ = Guid('{dae3bb9b-d304-497f-a168-a340042c8adb}')
    @winrt_commethod(6)
    def get_QualifierName(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_QualifierValue(self) -> WinRT_String: ...
    QualifierName = property(get_QualifierName, None)
    QualifierValue = property(get_QualifierValue, None)
class IResourceIndexer(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Resources.Management.IResourceIndexer'
    _iid_ = Guid('{2d4cf9a5-e32f-4ab2-8748-96350a016da3}')
    @winrt_commethod(6)
    def IndexFilePath(self, filePath: win32more.Windows.Foundation.Uri) -> win32more.Windows.ApplicationModel.Resources.Management.IndexedResourceCandidate: ...
    @winrt_commethod(7)
    def IndexFileContentsAsync(self, file: win32more.Windows.Foundation.Uri) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Resources.Management.IndexedResourceCandidate]]: ...
class IResourceIndexerFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Resources.Management.IResourceIndexerFactory'
    _iid_ = Guid('{b8de3f09-31cd-4d97-bd30-8d39f742bc61}')
    @winrt_commethod(6)
    def CreateResourceIndexer(self, projectRoot: win32more.Windows.Foundation.Uri) -> win32more.Windows.ApplicationModel.Resources.Management.ResourceIndexer: ...
class IResourceIndexerFactory2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Resources.Management.IResourceIndexerFactory2'
    _iid_ = Guid('{6040f18d-d5e5-4b60-9201-cd279cbcfed9}')
    @winrt_commethod(6)
    def CreateResourceIndexerWithExtension(self, projectRoot: win32more.Windows.Foundation.Uri, extensionDllPath: win32more.Windows.Foundation.Uri) -> win32more.Windows.ApplicationModel.Resources.Management.ResourceIndexer: ...
class IndexedResourceCandidate(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Resources.Management.IIndexedResourceCandidate
    _classid_ = 'Windows.ApplicationModel.Resources.Management.IndexedResourceCandidate'
    @winrt_mixinmethod
    def get_Type(self: win32more.Windows.ApplicationModel.Resources.Management.IIndexedResourceCandidate) -> win32more.Windows.ApplicationModel.Resources.Management.IndexedResourceType: ...
    @winrt_mixinmethod
    def get_Uri(self: win32more.Windows.ApplicationModel.Resources.Management.IIndexedResourceCandidate) -> win32more.Windows.Foundation.Uri: ...
    @winrt_mixinmethod
    def get_Metadata(self: win32more.Windows.ApplicationModel.Resources.Management.IIndexedResourceCandidate) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, WinRT_String]: ...
    @winrt_mixinmethod
    def get_Qualifiers(self: win32more.Windows.ApplicationModel.Resources.Management.IIndexedResourceCandidate) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Resources.Management.IndexedResourceQualifier]: ...
    @winrt_mixinmethod
    def get_ValueAsString(self: win32more.Windows.ApplicationModel.Resources.Management.IIndexedResourceCandidate) -> WinRT_String: ...
    @winrt_mixinmethod
    def GetQualifierValue(self: win32more.Windows.ApplicationModel.Resources.Management.IIndexedResourceCandidate, qualifierName: WinRT_String) -> WinRT_String: ...
    Metadata = property(get_Metadata, None)
    Qualifiers = property(get_Qualifiers, None)
    Type = property(get_Type, None)
    Uri = property(get_Uri, None)
    ValueAsString = property(get_ValueAsString, None)
class IndexedResourceQualifier(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Resources.Management.IIndexedResourceQualifier
    _classid_ = 'Windows.ApplicationModel.Resources.Management.IndexedResourceQualifier'
    @winrt_mixinmethod
    def get_QualifierName(self: win32more.Windows.ApplicationModel.Resources.Management.IIndexedResourceQualifier) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_QualifierValue(self: win32more.Windows.ApplicationModel.Resources.Management.IIndexedResourceQualifier) -> WinRT_String: ...
    QualifierName = property(get_QualifierName, None)
    QualifierValue = property(get_QualifierValue, None)
class IndexedResourceType(Enum, Int32):
    String = 0
    Path = 1
    EmbeddedData = 2
class ResourceIndexer(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Resources.Management.IResourceIndexer
    _classid_ = 'Windows.ApplicationModel.Resources.Management.ResourceIndexer'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 1:
            super().__init__(move=win32more.Windows.ApplicationModel.Resources.Management.ResourceIndexer.CreateResourceIndexer(*args))
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.ApplicationModel.Resources.Management.ResourceIndexer.CreateResourceIndexerWithExtension(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateResourceIndexer(cls: win32more.Windows.ApplicationModel.Resources.Management.IResourceIndexerFactory, projectRoot: win32more.Windows.Foundation.Uri) -> win32more.Windows.ApplicationModel.Resources.Management.ResourceIndexer: ...
    @winrt_factorymethod
    def CreateResourceIndexerWithExtension(cls: win32more.Windows.ApplicationModel.Resources.Management.IResourceIndexerFactory2, projectRoot: win32more.Windows.Foundation.Uri, extensionDllPath: win32more.Windows.Foundation.Uri) -> win32more.Windows.ApplicationModel.Resources.Management.ResourceIndexer: ...
    @winrt_mixinmethod
    def IndexFilePath(self: win32more.Windows.ApplicationModel.Resources.Management.IResourceIndexer, filePath: win32more.Windows.Foundation.Uri) -> win32more.Windows.ApplicationModel.Resources.Management.IndexedResourceCandidate: ...
    @winrt_mixinmethod
    def IndexFileContentsAsync(self: win32more.Windows.ApplicationModel.Resources.Management.IResourceIndexer, file: win32more.Windows.Foundation.Uri) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Resources.Management.IndexedResourceCandidate]]: ...
ResourceIndexerContract: UInt32 = 131072


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.ApplicationModel.Contacts
import win32more.Windows.ApplicationModel.Contacts.DataProvider
import win32more.Windows.Foundation
import win32more.Windows.Win32.System.WinRT
class ContactDataProviderConnection(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactDataProviderConnection
    _classid_ = 'Windows.ApplicationModel.Contacts.DataProvider.ContactDataProviderConnection'
    @winrt_mixinmethod
    def add_SyncRequested(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactDataProviderConnection, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Contacts.DataProvider.ContactDataProviderConnection, win32more.Windows.ApplicationModel.Contacts.DataProvider.ContactListSyncManagerSyncRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SyncRequested(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactDataProviderConnection, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_ServerSearchReadBatchRequested(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactDataProviderConnection, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Contacts.DataProvider.ContactDataProviderConnection, win32more.Windows.ApplicationModel.Contacts.DataProvider.ContactListServerSearchReadBatchRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ServerSearchReadBatchRequested(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactDataProviderConnection, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def Start(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactDataProviderConnection) -> Void: ...
    @winrt_mixinmethod
    def add_CreateOrUpdateContactRequested(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactDataProviderConnection2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Contacts.DataProvider.ContactDataProviderConnection, win32more.Windows.ApplicationModel.Contacts.DataProvider.ContactListCreateOrUpdateContactRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CreateOrUpdateContactRequested(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactDataProviderConnection2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_DeleteContactRequested(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactDataProviderConnection2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Contacts.DataProvider.ContactDataProviderConnection, win32more.Windows.ApplicationModel.Contacts.DataProvider.ContactListDeleteContactRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DeleteContactRequested(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactDataProviderConnection2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    SyncRequested = event()
    ServerSearchReadBatchRequested = event()
    CreateOrUpdateContactRequested = event()
    DeleteContactRequested = event()
class ContactDataProviderTriggerDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactDataProviderTriggerDetails
    _classid_ = 'Windows.ApplicationModel.Contacts.DataProvider.ContactDataProviderTriggerDetails'
    @winrt_mixinmethod
    def get_Connection(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactDataProviderTriggerDetails) -> win32more.Windows.ApplicationModel.Contacts.DataProvider.ContactDataProviderConnection: ...
    Connection = property(get_Connection, None)
class ContactListCreateOrUpdateContactRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListCreateOrUpdateContactRequest
    _classid_ = 'Windows.ApplicationModel.Contacts.DataProvider.ContactListCreateOrUpdateContactRequest'
    @winrt_mixinmethod
    def get_ContactListId(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListCreateOrUpdateContactRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Contact(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListCreateOrUpdateContactRequest) -> win32more.Windows.ApplicationModel.Contacts.Contact: ...
    @winrt_mixinmethod
    def ReportCompletedAsync(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListCreateOrUpdateContactRequest, createdOrUpdatedContact: win32more.Windows.ApplicationModel.Contacts.Contact) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedAsync(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListCreateOrUpdateContactRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    Contact = property(get_Contact, None)
    ContactListId = property(get_ContactListId, None)
class ContactListCreateOrUpdateContactRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListCreateOrUpdateContactRequestEventArgs
    _classid_ = 'Windows.ApplicationModel.Contacts.DataProvider.ContactListCreateOrUpdateContactRequestEventArgs'
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListCreateOrUpdateContactRequestEventArgs) -> win32more.Windows.ApplicationModel.Contacts.DataProvider.ContactListCreateOrUpdateContactRequest: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListCreateOrUpdateContactRequestEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class ContactListDeleteContactRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListDeleteContactRequest
    _classid_ = 'Windows.ApplicationModel.Contacts.DataProvider.ContactListDeleteContactRequest'
    @winrt_mixinmethod
    def get_ContactListId(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListDeleteContactRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ContactId(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListDeleteContactRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def ReportCompletedAsync(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListDeleteContactRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedAsync(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListDeleteContactRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    ContactId = property(get_ContactId, None)
    ContactListId = property(get_ContactListId, None)
class ContactListDeleteContactRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListDeleteContactRequestEventArgs
    _classid_ = 'Windows.ApplicationModel.Contacts.DataProvider.ContactListDeleteContactRequestEventArgs'
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListDeleteContactRequestEventArgs) -> win32more.Windows.ApplicationModel.Contacts.DataProvider.ContactListDeleteContactRequest: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListDeleteContactRequestEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class ContactListServerSearchReadBatchRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListServerSearchReadBatchRequest
    _classid_ = 'Windows.ApplicationModel.Contacts.DataProvider.ContactListServerSearchReadBatchRequest'
    @winrt_mixinmethod
    def get_SessionId(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListServerSearchReadBatchRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ContactListId(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListServerSearchReadBatchRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Options(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListServerSearchReadBatchRequest) -> win32more.Windows.ApplicationModel.Contacts.ContactQueryOptions: ...
    @winrt_mixinmethod
    def get_SuggestedBatchSize(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListServerSearchReadBatchRequest) -> UInt32: ...
    @winrt_mixinmethod
    def SaveContactAsync(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListServerSearchReadBatchRequest, contact: win32more.Windows.ApplicationModel.Contacts.Contact) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportCompletedAsync(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListServerSearchReadBatchRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedAsync(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListServerSearchReadBatchRequest, batchStatus: win32more.Windows.ApplicationModel.Contacts.ContactBatchStatus) -> win32more.Windows.Foundation.IAsyncAction: ...
    ContactListId = property(get_ContactListId, None)
    Options = property(get_Options, None)
    SessionId = property(get_SessionId, None)
    SuggestedBatchSize = property(get_SuggestedBatchSize, None)
class ContactListServerSearchReadBatchRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListServerSearchReadBatchRequestEventArgs
    _classid_ = 'Windows.ApplicationModel.Contacts.DataProvider.ContactListServerSearchReadBatchRequestEventArgs'
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListServerSearchReadBatchRequestEventArgs) -> win32more.Windows.ApplicationModel.Contacts.DataProvider.ContactListServerSearchReadBatchRequest: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListServerSearchReadBatchRequestEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class ContactListSyncManagerSyncRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListSyncManagerSyncRequest
    _classid_ = 'Windows.ApplicationModel.Contacts.DataProvider.ContactListSyncManagerSyncRequest'
    @winrt_mixinmethod
    def get_ContactListId(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListSyncManagerSyncRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def ReportCompletedAsync(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListSyncManagerSyncRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def ReportFailedAsync(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListSyncManagerSyncRequest) -> win32more.Windows.Foundation.IAsyncAction: ...
    ContactListId = property(get_ContactListId, None)
class ContactListSyncManagerSyncRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListSyncManagerSyncRequestEventArgs
    _classid_ = 'Windows.ApplicationModel.Contacts.DataProvider.ContactListSyncManagerSyncRequestEventArgs'
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListSyncManagerSyncRequestEventArgs) -> win32more.Windows.ApplicationModel.Contacts.DataProvider.ContactListSyncManagerSyncRequest: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.ApplicationModel.Contacts.DataProvider.IContactListSyncManagerSyncRequestEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class IContactDataProviderConnection(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Contacts.DataProvider.IContactDataProviderConnection'
    _iid_ = Guid('{1a398a52-8c9d-4d6f-a4e0-111e9a125a30}')
    @winrt_commethod(6)
    def add_SyncRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Contacts.DataProvider.ContactDataProviderConnection, win32more.Windows.ApplicationModel.Contacts.DataProvider.ContactListSyncManagerSyncRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_SyncRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(8)
    def add_ServerSearchReadBatchRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Contacts.DataProvider.ContactDataProviderConnection, win32more.Windows.ApplicationModel.Contacts.DataProvider.ContactListServerSearchReadBatchRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_ServerSearchReadBatchRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def Start(self) -> Void: ...
    SyncRequested = event()
    ServerSearchReadBatchRequested = event()
class IContactDataProviderConnection2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Contacts.DataProvider.IContactDataProviderConnection2'
    _iid_ = Guid('{a1d327b0-196c-4bfd-8f0f-c68d67f249d3}')
    @winrt_commethod(6)
    def add_CreateOrUpdateContactRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Contacts.DataProvider.ContactDataProviderConnection, win32more.Windows.ApplicationModel.Contacts.DataProvider.ContactListCreateOrUpdateContactRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_CreateOrUpdateContactRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(8)
    def add_DeleteContactRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Contacts.DataProvider.ContactDataProviderConnection, win32more.Windows.ApplicationModel.Contacts.DataProvider.ContactListDeleteContactRequestEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_DeleteContactRequested(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    CreateOrUpdateContactRequested = event()
    DeleteContactRequested = event()
class IContactDataProviderTriggerDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Contacts.DataProvider.IContactDataProviderTriggerDetails'
    _iid_ = Guid('{527104be-3c62-43c8-9ae7-db531685cd99}')
    @winrt_commethod(6)
    def get_Connection(self) -> win32more.Windows.ApplicationModel.Contacts.DataProvider.ContactDataProviderConnection: ...
    Connection = property(get_Connection, None)
class IContactListCreateOrUpdateContactRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Contacts.DataProvider.IContactListCreateOrUpdateContactRequest'
    _iid_ = Guid('{b4af411f-c849-47d0-b119-91cf605b2f2a}')
    @winrt_commethod(6)
    def get_ContactListId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Contact(self) -> win32more.Windows.ApplicationModel.Contacts.Contact: ...
    @winrt_commethod(8)
    def ReportCompletedAsync(self, createdOrUpdatedContact: win32more.Windows.ApplicationModel.Contacts.Contact) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(9)
    def ReportFailedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    Contact = property(get_Contact, None)
    ContactListId = property(get_ContactListId, None)
class IContactListCreateOrUpdateContactRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Contacts.DataProvider.IContactListCreateOrUpdateContactRequestEventArgs'
    _iid_ = Guid('{851c1690-1a51-4b0c-aeef-1240ac5bed75}')
    @winrt_commethod(6)
    def get_Request(self) -> win32more.Windows.ApplicationModel.Contacts.DataProvider.ContactListCreateOrUpdateContactRequest: ...
    @winrt_commethod(7)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class IContactListDeleteContactRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Contacts.DataProvider.IContactListDeleteContactRequest'
    _iid_ = Guid('{5e114687-ce03-4de5-8557-9ccf552d472a}')
    @winrt_commethod(6)
    def get_ContactListId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_ContactId(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def ReportCompletedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(9)
    def ReportFailedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    ContactId = property(get_ContactId, None)
    ContactListId = property(get_ContactListId, None)
class IContactListDeleteContactRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Contacts.DataProvider.IContactListDeleteContactRequestEventArgs'
    _iid_ = Guid('{b22054a1-e8fa-4db5-9389-2d12ee7d15ee}')
    @winrt_commethod(6)
    def get_Request(self) -> win32more.Windows.ApplicationModel.Contacts.DataProvider.ContactListDeleteContactRequest: ...
    @winrt_commethod(7)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class IContactListServerSearchReadBatchRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Contacts.DataProvider.IContactListServerSearchReadBatchRequest'
    _iid_ = Guid('{ba776a97-4030-4925-9fb4-143b295e653b}')
    @winrt_commethod(6)
    def get_SessionId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_ContactListId(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_Options(self) -> win32more.Windows.ApplicationModel.Contacts.ContactQueryOptions: ...
    @winrt_commethod(9)
    def get_SuggestedBatchSize(self) -> UInt32: ...
    @winrt_commethod(10)
    def SaveContactAsync(self, contact: win32more.Windows.ApplicationModel.Contacts.Contact) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(11)
    def ReportCompletedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(12)
    def ReportFailedAsync(self, batchStatus: win32more.Windows.ApplicationModel.Contacts.ContactBatchStatus) -> win32more.Windows.Foundation.IAsyncAction: ...
    ContactListId = property(get_ContactListId, None)
    Options = property(get_Options, None)
    SessionId = property(get_SessionId, None)
    SuggestedBatchSize = property(get_SuggestedBatchSize, None)
class IContactListServerSearchReadBatchRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Contacts.DataProvider.IContactListServerSearchReadBatchRequestEventArgs'
    _iid_ = Guid('{1a27e87b-69d7-4e4e-8042-861cba61471e}')
    @winrt_commethod(6)
    def get_Request(self) -> win32more.Windows.ApplicationModel.Contacts.DataProvider.ContactListServerSearchReadBatchRequest: ...
    @winrt_commethod(7)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)
class IContactListSyncManagerSyncRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Contacts.DataProvider.IContactListSyncManagerSyncRequest'
    _iid_ = Guid('{3c0e57a4-c4e7-4970-9a8f-9a66a2bb6c1a}')
    @winrt_commethod(6)
    def get_ContactListId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def ReportCompletedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(8)
    def ReportFailedAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    ContactListId = property(get_ContactListId, None)
class IContactListSyncManagerSyncRequestEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Contacts.DataProvider.IContactListSyncManagerSyncRequestEventArgs'
    _iid_ = Guid('{158e4dac-446d-4f10-afc2-02683ec533a6}')
    @winrt_commethod(6)
    def get_Request(self) -> win32more.Windows.ApplicationModel.Contacts.DataProvider.ContactListSyncManagerSyncRequest: ...
    @winrt_commethod(7)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    Request = property(get_Request, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.System.Inventory
import win32more.Windows.Win32.System.WinRT
class IInstalledDesktopApp(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Inventory.IInstalledDesktopApp'
    _iid_ = Guid('{75eab8ed-c0bc-5364-4c28-166e0545167a}')
    @winrt_commethod(6)
    def get_Id(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_DisplayName(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_Publisher(self) -> WinRT_String: ...
    @winrt_commethod(9)
    def get_DisplayVersion(self) -> WinRT_String: ...
    DisplayName = property(get_DisplayName, None)
    DisplayVersion = property(get_DisplayVersion, None)
    Id = property(get_Id, None)
    Publisher = property(get_Publisher, None)
class IInstalledDesktopAppStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.System.Inventory.IInstalledDesktopAppStatics'
    _iid_ = Guid('{264cf74e-21cd-5f9b-6056-7866ad72489a}')
    @winrt_commethod(6)
    def GetInventoryAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.System.Inventory.InstalledDesktopApp]]: ...
class InstalledDesktopApp(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.System.Inventory.IInstalledDesktopApp
    _classid_ = 'Windows.System.Inventory.InstalledDesktopApp'
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.System.Inventory.IInstalledDesktopApp) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_DisplayName(self: win32more.Windows.System.Inventory.IInstalledDesktopApp) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Publisher(self: win32more.Windows.System.Inventory.IInstalledDesktopApp) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_DisplayVersion(self: win32more.Windows.System.Inventory.IInstalledDesktopApp) -> WinRT_String: ...
    @winrt_mixinmethod
    def ToString(self: win32more.Windows.Foundation.IStringable) -> WinRT_String: ...
    @winrt_classmethod
    def GetInventoryAsync(cls: win32more.Windows.System.Inventory.IInstalledDesktopAppStatics) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.System.Inventory.InstalledDesktopApp]]: ...
    DisplayName = property(get_DisplayName, None)
    DisplayVersion = property(get_DisplayVersion, None)
    Id = property(get_Id, None)
    Publisher = property(get_Publisher, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.System.Shutdown
MAX_REASON_NAME_LEN: UInt32 = 64
MAX_REASON_DESC_LEN: UInt32 = 256
MAX_REASON_BUGID_LEN: UInt32 = 32
MAX_REASON_COMMENT_LEN: UInt32 = 512
SHUTDOWN_TYPE_LEN: UInt32 = 32
POLICY_SHOWREASONUI_NEVER: UInt32 = 0
POLICY_SHOWREASONUI_ALWAYS: UInt32 = 1
POLICY_SHOWREASONUI_WORKSTATIONONLY: UInt32 = 2
POLICY_SHOWREASONUI_SERVERONLY: UInt32 = 3
SNAPSHOT_POLICY_NEVER: UInt32 = 0
SNAPSHOT_POLICY_ALWAYS: UInt32 = 1
SNAPSHOT_POLICY_UNPLANNED: UInt32 = 2
MAX_NUM_REASONS: UInt32 = 256
@winfunctype('ADVAPI32.dll')
def InitiateSystemShutdownA(lpMachineName: win32more.Windows.Win32.Foundation.PSTR, lpMessage: win32more.Windows.Win32.Foundation.PSTR, dwTimeout: UInt32, bForceAppsClosed: win32more.Windows.Win32.Foundation.BOOL, bRebootAfterShutdown: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def InitiateSystemShutdownW(lpMachineName: win32more.Windows.Win32.Foundation.PWSTR, lpMessage: win32more.Windows.Win32.Foundation.PWSTR, dwTimeout: UInt32, bForceAppsClosed: win32more.Windows.Win32.Foundation.BOOL, bRebootAfterShutdown: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.BOOL: ...
InitiateSystemShutdown = UnicodeAlias('InitiateSystemShutdownW')
@winfunctype('ADVAPI32.dll')
def AbortSystemShutdownA(lpMachineName: win32more.Windows.Win32.Foundation.PSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def AbortSystemShutdownW(lpMachineName: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
AbortSystemShutdown = UnicodeAlias('AbortSystemShutdownW')
@winfunctype('ADVAPI32.dll')
def InitiateSystemShutdownExA(lpMachineName: win32more.Windows.Win32.Foundation.PSTR, lpMessage: win32more.Windows.Win32.Foundation.PSTR, dwTimeout: UInt32, bForceAppsClosed: win32more.Windows.Win32.Foundation.BOOL, bRebootAfterShutdown: win32more.Windows.Win32.Foundation.BOOL, dwReason: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('ADVAPI32.dll')
def InitiateSystemShutdownExW(lpMachineName: win32more.Windows.Win32.Foundation.PWSTR, lpMessage: win32more.Windows.Win32.Foundation.PWSTR, dwTimeout: UInt32, bForceAppsClosed: win32more.Windows.Win32.Foundation.BOOL, bRebootAfterShutdown: win32more.Windows.Win32.Foundation.BOOL, dwReason: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON) -> win32more.Windows.Win32.Foundation.BOOL: ...
InitiateSystemShutdownEx = UnicodeAlias('InitiateSystemShutdownExW')
@winfunctype('ADVAPI32.dll')
def InitiateShutdownA(lpMachineName: win32more.Windows.Win32.Foundation.PSTR, lpMessage: win32more.Windows.Win32.Foundation.PSTR, dwGracePeriod: UInt32, dwShutdownFlags: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_FLAGS, dwReason: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON) -> UInt32: ...
@winfunctype('ADVAPI32.dll')
def InitiateShutdownW(lpMachineName: win32more.Windows.Win32.Foundation.PWSTR, lpMessage: win32more.Windows.Win32.Foundation.PWSTR, dwGracePeriod: UInt32, dwShutdownFlags: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_FLAGS, dwReason: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON) -> UInt32: ...
InitiateShutdown = UnicodeAlias('InitiateShutdownW')
@winfunctype('ADVAPI32.dll')
def CheckForHiberboot(pHiberboot: POINTER(win32more.Windows.Win32.Foundation.BOOLEAN), bClearFlag: win32more.Windows.Win32.Foundation.BOOLEAN) -> UInt32: ...
@winfunctype('USER32.dll')
def ExitWindowsEx(uFlags: win32more.Windows.Win32.System.Shutdown.EXIT_WINDOWS_FLAGS, dwReason: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def LockWorkStation() -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def ShutdownBlockReasonCreate(hWnd: win32more.Windows.Win32.Foundation.HWND, pwszReason: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def ShutdownBlockReasonQuery(hWnd: win32more.Windows.Win32.Foundation.HWND, pwszBuff: win32more.Windows.Win32.Foundation.PWSTR, pcchBuff: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('USER32.dll')
def ShutdownBlockReasonDestroy(hWnd: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.BOOL: ...
EXIT_WINDOWS_FLAGS = UInt32
EWX_LOGOFF: win32more.Windows.Win32.System.Shutdown.EXIT_WINDOWS_FLAGS = 0
EWX_SHUTDOWN: win32more.Windows.Win32.System.Shutdown.EXIT_WINDOWS_FLAGS = 1
EWX_REBOOT: win32more.Windows.Win32.System.Shutdown.EXIT_WINDOWS_FLAGS = 2
EWX_FORCE: win32more.Windows.Win32.System.Shutdown.EXIT_WINDOWS_FLAGS = 4
EWX_POWEROFF: win32more.Windows.Win32.System.Shutdown.EXIT_WINDOWS_FLAGS = 8
EWX_FORCEIFHUNG: win32more.Windows.Win32.System.Shutdown.EXIT_WINDOWS_FLAGS = 16
EWX_QUICKRESOLVE: win32more.Windows.Win32.System.Shutdown.EXIT_WINDOWS_FLAGS = 32
EWX_RESTARTAPPS: win32more.Windows.Win32.System.Shutdown.EXIT_WINDOWS_FLAGS = 64
EWX_HYBRID_SHUTDOWN: win32more.Windows.Win32.System.Shutdown.EXIT_WINDOWS_FLAGS = 4194304
EWX_BOOTOPTIONS: win32more.Windows.Win32.System.Shutdown.EXIT_WINDOWS_FLAGS = 16777216
EWX_ARSO: win32more.Windows.Win32.System.Shutdown.EXIT_WINDOWS_FLAGS = 67108864
EWX_CHECK_SAFE_FOR_SERVER: win32more.Windows.Win32.System.Shutdown.EXIT_WINDOWS_FLAGS = 134217728
EWX_SYSTEM_INITIATED: win32more.Windows.Win32.System.Shutdown.EXIT_WINDOWS_FLAGS = 268435456
SHUTDOWN_FLAGS = UInt32
SHUTDOWN_FORCE_OTHERS: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_FLAGS = 1
SHUTDOWN_FORCE_SELF: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_FLAGS = 2
SHUTDOWN_RESTART: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_FLAGS = 4
SHUTDOWN_POWEROFF: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_FLAGS = 8
SHUTDOWN_NOREBOOT: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_FLAGS = 16
SHUTDOWN_GRACE_OVERRIDE: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_FLAGS = 32
SHUTDOWN_INSTALL_UPDATES: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_FLAGS = 64
SHUTDOWN_RESTARTAPPS: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_FLAGS = 128
SHUTDOWN_SKIP_SVC_PRESHUTDOWN: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_FLAGS = 256
SHUTDOWN_HYBRID: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_FLAGS = 512
SHUTDOWN_RESTART_BOOTOPTIONS: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_FLAGS = 1024
SHUTDOWN_SOFT_REBOOT: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_FLAGS = 2048
SHUTDOWN_MOBILE_UI: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_FLAGS = 4096
SHUTDOWN_ARSO: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_FLAGS = 8192
SHUTDOWN_CHECK_SAFE_FOR_SERVER: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_FLAGS = 16384
SHUTDOWN_VAIL_CONTAINER: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_FLAGS = 32768
SHUTDOWN_SYSTEM_INITIATED: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_FLAGS = 65536
SHUTDOWN_REASON = UInt32
SHTDN_REASON_NONE: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 0
SHTDN_REASON_FLAG_COMMENT_REQUIRED: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 16777216
SHTDN_REASON_FLAG_DIRTY_PROBLEM_ID_REQUIRED: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 33554432
SHTDN_REASON_FLAG_CLEAN_UI: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 67108864
SHTDN_REASON_FLAG_DIRTY_UI: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 134217728
SHTDN_REASON_FLAG_MOBILE_UI_RESERVED: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 268435456
SHTDN_REASON_FLAG_USER_DEFINED: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 1073741824
SHTDN_REASON_FLAG_PLANNED: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 2147483648
SHTDN_REASON_MAJOR_OTHER: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 0
SHTDN_REASON_MAJOR_NONE: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 0
SHTDN_REASON_MAJOR_HARDWARE: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 65536
SHTDN_REASON_MAJOR_OPERATINGSYSTEM: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 131072
SHTDN_REASON_MAJOR_SOFTWARE: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 196608
SHTDN_REASON_MAJOR_APPLICATION: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 262144
SHTDN_REASON_MAJOR_SYSTEM: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 327680
SHTDN_REASON_MAJOR_POWER: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 393216
SHTDN_REASON_MAJOR_LEGACY_API: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 458752
SHTDN_REASON_MINOR_OTHER: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 0
SHTDN_REASON_MINOR_NONE: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 255
SHTDN_REASON_MINOR_MAINTENANCE: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 1
SHTDN_REASON_MINOR_INSTALLATION: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 2
SHTDN_REASON_MINOR_UPGRADE: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 3
SHTDN_REASON_MINOR_RECONFIG: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 4
SHTDN_REASON_MINOR_HUNG: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 5
SHTDN_REASON_MINOR_UNSTABLE: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 6
SHTDN_REASON_MINOR_DISK: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 7
SHTDN_REASON_MINOR_PROCESSOR: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 8
SHTDN_REASON_MINOR_NETWORKCARD: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 9
SHTDN_REASON_MINOR_POWER_SUPPLY: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 10
SHTDN_REASON_MINOR_CORDUNPLUGGED: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 11
SHTDN_REASON_MINOR_ENVIRONMENT: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 12
SHTDN_REASON_MINOR_HARDWARE_DRIVER: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 13
SHTDN_REASON_MINOR_OTHERDRIVER: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 14
SHTDN_REASON_MINOR_BLUESCREEN: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 15
SHTDN_REASON_MINOR_SERVICEPACK: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 16
SHTDN_REASON_MINOR_HOTFIX: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 17
SHTDN_REASON_MINOR_SECURITYFIX: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 18
SHTDN_REASON_MINOR_SECURITY: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 19
SHTDN_REASON_MINOR_NETWORK_CONNECTIVITY: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 20
SHTDN_REASON_MINOR_WMI: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 21
SHTDN_REASON_MINOR_SERVICEPACK_UNINSTALL: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 22
SHTDN_REASON_MINOR_HOTFIX_UNINSTALL: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 23
SHTDN_REASON_MINOR_SECURITYFIX_UNINSTALL: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 24
SHTDN_REASON_MINOR_MMC: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 25
SHTDN_REASON_MINOR_SYSTEMRESTORE: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 26
SHTDN_REASON_MINOR_TERMSRV: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 32
SHTDN_REASON_MINOR_DC_PROMOTION: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 33
SHTDN_REASON_MINOR_DC_DEMOTION: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 34
SHTDN_REASON_UNKNOWN: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 255
SHTDN_REASON_LEGACY_API: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 2147942400
SHTDN_REASON_VALID_BIT_MASK: win32more.Windows.Win32.System.Shutdown.SHUTDOWN_REASON = 3238002687


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.ApplicationModel
import win32more.Windows.ApplicationModel.Activation
import win32more.Windows.ApplicationModel.Core
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.System
import win32more.Windows.UI.Core
import win32more.Windows.Win32.System.WinRT
class AppListEntry(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Core.IAppListEntry
    _classid_ = 'Windows.ApplicationModel.Core.AppListEntry'
    @winrt_mixinmethod
    def get_DisplayInfo(self: win32more.Windows.ApplicationModel.Core.IAppListEntry) -> win32more.Windows.ApplicationModel.AppDisplayInfo: ...
    @winrt_mixinmethod
    def LaunchAsync(self: win32more.Windows.ApplicationModel.Core.IAppListEntry) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_mixinmethod
    def get_AppUserModelId(self: win32more.Windows.ApplicationModel.Core.IAppListEntry2) -> WinRT_String: ...
    @winrt_mixinmethod
    def LaunchForUserAsync(self: win32more.Windows.ApplicationModel.Core.IAppListEntry3, user: win32more.Windows.System.User) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    @winrt_mixinmethod
    def get_AppInfo(self: win32more.Windows.ApplicationModel.Core.IAppListEntry4) -> win32more.Windows.ApplicationModel.AppInfo: ...
    AppInfo = property(get_AppInfo, None)
    AppUserModelId = property(get_AppUserModelId, None)
    DisplayInfo = property(get_DisplayInfo, None)
class AppRestartFailureReason(Enum, Int32):
    RestartPending = 0
    NotInForeground = 1
    InvalidUser = 2
    Other = 3
class _CoreApplication_Meta_(ComPtr.__class__):
    pass
class CoreApplication(ComPtr, metaclass=_CoreApplication_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Core.CoreApplication'
    @winrt_classmethod
    def CreateNewViewWithViewSource(cls: win32more.Windows.ApplicationModel.Core.ICoreImmersiveApplication3, viewSource: win32more.Windows.ApplicationModel.Core.IFrameworkViewSource) -> win32more.Windows.ApplicationModel.Core.CoreApplicationView: ...
    @winrt_classmethod
    def CreateNewViewFromMainView(cls: win32more.Windows.ApplicationModel.Core.ICoreImmersiveApplication2) -> win32more.Windows.ApplicationModel.Core.CoreApplicationView: ...
    @winrt_classmethod
    def add_UnhandledErrorDetected(cls: win32more.Windows.ApplicationModel.Core.ICoreApplicationUnhandledError, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.ApplicationModel.Core.UnhandledErrorDetectedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_UnhandledErrorDetected(cls: win32more.Windows.ApplicationModel.Core.ICoreApplicationUnhandledError, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def IncrementApplicationUseCount(cls: win32more.Windows.ApplicationModel.Core.ICoreApplicationUseCount) -> Void: ...
    @winrt_classmethod
    def DecrementApplicationUseCount(cls: win32more.Windows.ApplicationModel.Core.ICoreApplicationUseCount) -> Void: ...
    @winrt_classmethod
    def get_Views(cls: win32more.Windows.ApplicationModel.Core.ICoreImmersiveApplication) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Core.CoreApplicationView]: ...
    @winrt_classmethod
    def CreateNewView(cls: win32more.Windows.ApplicationModel.Core.ICoreImmersiveApplication, runtimeType: WinRT_String, entryPoint: WinRT_String) -> win32more.Windows.ApplicationModel.Core.CoreApplicationView: ...
    @winrt_classmethod
    def get_MainView(cls: win32more.Windows.ApplicationModel.Core.ICoreImmersiveApplication) -> win32more.Windows.ApplicationModel.Core.CoreApplicationView: ...
    @winrt_classmethod
    def Exit(cls: win32more.Windows.ApplicationModel.Core.ICoreApplicationExit) -> Void: ...
    @winrt_classmethod
    def add_Exiting(cls: win32more.Windows.ApplicationModel.Core.ICoreApplicationExit, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_Exiting(cls: win32more.Windows.ApplicationModel.Core.ICoreApplicationExit, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def RequestRestartAsync(cls: win32more.Windows.ApplicationModel.Core.ICoreApplication3, launchArguments: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.Core.AppRestartFailureReason]: ...
    @winrt_classmethod
    def RequestRestartForUserAsync(cls: win32more.Windows.ApplicationModel.Core.ICoreApplication3, user: win32more.Windows.System.User, launchArguments: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.Core.AppRestartFailureReason]: ...
    @winrt_classmethod
    def add_BackgroundActivated(cls: win32more.Windows.ApplicationModel.Core.ICoreApplication2, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.ApplicationModel.Activation.BackgroundActivatedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_BackgroundActivated(cls: win32more.Windows.ApplicationModel.Core.ICoreApplication2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def add_LeavingBackground(cls: win32more.Windows.ApplicationModel.Core.ICoreApplication2, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.ApplicationModel.LeavingBackgroundEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_LeavingBackground(cls: win32more.Windows.ApplicationModel.Core.ICoreApplication2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def add_EnteredBackground(cls: win32more.Windows.ApplicationModel.Core.ICoreApplication2, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.ApplicationModel.EnteredBackgroundEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_EnteredBackground(cls: win32more.Windows.ApplicationModel.Core.ICoreApplication2, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def EnablePrelaunch(cls: win32more.Windows.ApplicationModel.Core.ICoreApplication2, value: Boolean) -> Void: ...
    @winrt_classmethod
    def get_Id(cls: win32more.Windows.ApplicationModel.Core.ICoreApplication) -> WinRT_String: ...
    @winrt_classmethod
    def add_Suspending(cls: win32more.Windows.ApplicationModel.Core.ICoreApplication, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.ApplicationModel.SuspendingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_Suspending(cls: win32more.Windows.ApplicationModel.Core.ICoreApplication, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def add_Resuming(cls: win32more.Windows.ApplicationModel.Core.ICoreApplication, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_Resuming(cls: win32more.Windows.ApplicationModel.Core.ICoreApplication, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_Properties(cls: win32more.Windows.ApplicationModel.Core.ICoreApplication) -> win32more.Windows.Foundation.Collections.IPropertySet: ...
    @winrt_classmethod
    def GetCurrentView(cls: win32more.Windows.ApplicationModel.Core.ICoreApplication) -> win32more.Windows.ApplicationModel.Core.CoreApplicationView: ...
    @winrt_classmethod
    def Run(cls: win32more.Windows.ApplicationModel.Core.ICoreApplication, viewSource: win32more.Windows.ApplicationModel.Core.IFrameworkViewSource) -> Void: ...
    @winrt_classmethod
    def RunWithActivationFactories(cls: win32more.Windows.ApplicationModel.Core.ICoreApplication, activationFactoryCallback: win32more.Windows.Foundation.IGetActivationFactory) -> Void: ...
    _CoreApplication_Meta_.Id = property(get_Id, None)
    _CoreApplication_Meta_.MainView = property(get_MainView, None)
    _CoreApplication_Meta_.Properties = property(get_Properties, None)
    _CoreApplication_Meta_.Views = property(get_Views, None)
class CoreApplicationView(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Core.ICoreApplicationView
    _classid_ = 'Windows.ApplicationModel.Core.CoreApplicationView'
    @winrt_mixinmethod
    def get_CoreWindow(self: win32more.Windows.ApplicationModel.Core.ICoreApplicationView) -> win32more.Windows.UI.Core.CoreWindow: ...
    @winrt_mixinmethod
    def add_Activated(self: win32more.Windows.ApplicationModel.Core.ICoreApplicationView, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Core.CoreApplicationView, win32more.Windows.ApplicationModel.Activation.IActivatedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_Activated(self: win32more.Windows.ApplicationModel.Core.ICoreApplicationView, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_IsMain(self: win32more.Windows.ApplicationModel.Core.ICoreApplicationView) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsHosted(self: win32more.Windows.ApplicationModel.Core.ICoreApplicationView) -> Boolean: ...
    @winrt_mixinmethod
    def get_Dispatcher(self: win32more.Windows.ApplicationModel.Core.ICoreApplicationView2) -> win32more.Windows.UI.Core.CoreDispatcher: ...
    @winrt_mixinmethod
    def get_IsComponent(self: win32more.Windows.ApplicationModel.Core.ICoreApplicationView3) -> Boolean: ...
    @winrt_mixinmethod
    def get_TitleBar(self: win32more.Windows.ApplicationModel.Core.ICoreApplicationView3) -> win32more.Windows.ApplicationModel.Core.CoreApplicationViewTitleBar: ...
    @winrt_mixinmethod
    def add_HostedViewClosing(self: win32more.Windows.ApplicationModel.Core.ICoreApplicationView3, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Core.CoreApplicationView, win32more.Windows.ApplicationModel.Core.HostedViewClosingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_HostedViewClosing(self: win32more.Windows.ApplicationModel.Core.ICoreApplicationView3, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_Properties(self: win32more.Windows.ApplicationModel.Core.ICoreApplicationView5) -> win32more.Windows.Foundation.Collections.IPropertySet: ...
    @winrt_mixinmethod
    def get_DispatcherQueue(self: win32more.Windows.ApplicationModel.Core.ICoreApplicationView6) -> win32more.Windows.System.DispatcherQueue: ...
    CoreWindow = property(get_CoreWindow, None)
    Dispatcher = property(get_Dispatcher, None)
    DispatcherQueue = property(get_DispatcherQueue, None)
    IsComponent = property(get_IsComponent, None)
    IsHosted = property(get_IsHosted, None)
    IsMain = property(get_IsMain, None)
    Properties = property(get_Properties, None)
    TitleBar = property(get_TitleBar, None)
    Activated = event()
    HostedViewClosing = event()
class CoreApplicationViewTitleBar(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Core.ICoreApplicationViewTitleBar
    _classid_ = 'Windows.ApplicationModel.Core.CoreApplicationViewTitleBar'
    @winrt_mixinmethod
    def put_ExtendViewIntoTitleBar(self: win32more.Windows.ApplicationModel.Core.ICoreApplicationViewTitleBar, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_ExtendViewIntoTitleBar(self: win32more.Windows.ApplicationModel.Core.ICoreApplicationViewTitleBar) -> Boolean: ...
    @winrt_mixinmethod
    def get_SystemOverlayLeftInset(self: win32more.Windows.ApplicationModel.Core.ICoreApplicationViewTitleBar) -> Double: ...
    @winrt_mixinmethod
    def get_SystemOverlayRightInset(self: win32more.Windows.ApplicationModel.Core.ICoreApplicationViewTitleBar) -> Double: ...
    @winrt_mixinmethod
    def get_Height(self: win32more.Windows.ApplicationModel.Core.ICoreApplicationViewTitleBar) -> Double: ...
    @winrt_mixinmethod
    def add_LayoutMetricsChanged(self: win32more.Windows.ApplicationModel.Core.ICoreApplicationViewTitleBar, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Core.CoreApplicationViewTitleBar, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_LayoutMetricsChanged(self: win32more.Windows.ApplicationModel.Core.ICoreApplicationViewTitleBar, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_IsVisible(self: win32more.Windows.ApplicationModel.Core.ICoreApplicationViewTitleBar) -> Boolean: ...
    @winrt_mixinmethod
    def add_IsVisibleChanged(self: win32more.Windows.ApplicationModel.Core.ICoreApplicationViewTitleBar, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Core.CoreApplicationViewTitleBar, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_IsVisibleChanged(self: win32more.Windows.ApplicationModel.Core.ICoreApplicationViewTitleBar, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    ExtendViewIntoTitleBar = property(get_ExtendViewIntoTitleBar, put_ExtendViewIntoTitleBar)
    Height = property(get_Height, None)
    IsVisible = property(get_IsVisible, None)
    SystemOverlayLeftInset = property(get_SystemOverlayLeftInset, None)
    SystemOverlayRightInset = property(get_SystemOverlayRightInset, None)
    LayoutMetricsChanged = event()
    IsVisibleChanged = event()
class HostedViewClosingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Core.IHostedViewClosingEventArgs
    _classid_ = 'Windows.ApplicationModel.Core.HostedViewClosingEventArgs'
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.ApplicationModel.Core.IHostedViewClosingEventArgs) -> win32more.Windows.Foundation.Deferral: ...
class IAppListEntry(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Core.IAppListEntry'
    _iid_ = Guid('{ef00f07f-2108-490a-877a-8a9f17c25fad}')
    @winrt_commethod(6)
    def get_DisplayInfo(self) -> win32more.Windows.ApplicationModel.AppDisplayInfo: ...
    @winrt_commethod(7)
    def LaunchAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    DisplayInfo = property(get_DisplayInfo, None)
class IAppListEntry2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Core.IAppListEntry2'
    _iid_ = Guid('{d0a618ad-bf35-42ac-ac06-86eeeb41d04b}')
    @winrt_commethod(6)
    def get_AppUserModelId(self) -> WinRT_String: ...
    AppUserModelId = property(get_AppUserModelId, None)
class IAppListEntry3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Core.IAppListEntry3'
    _iid_ = Guid('{6099f28d-fc32-470a-bc69-4b061a76ef2e}')
    @winrt_commethod(6)
    def LaunchForUserAsync(self, user: win32more.Windows.System.User) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
class IAppListEntry4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Core.IAppListEntry4'
    _iid_ = Guid('{2a131ed2-56f5-487c-8697-5166f3b33da0}')
    @winrt_commethod(6)
    def get_AppInfo(self) -> win32more.Windows.ApplicationModel.AppInfo: ...
    AppInfo = property(get_AppInfo, None)
class ICoreApplication(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Core.ICoreApplication'
    _iid_ = Guid('{0aacf7a4-5e1d-49df-8034-fb6a68bc5ed1}')
    @winrt_commethod(6)
    def get_Id(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def add_Suspending(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.ApplicationModel.SuspendingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(8)
    def remove_Suspending(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(9)
    def add_Resuming(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(10)
    def remove_Resuming(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(11)
    def get_Properties(self) -> win32more.Windows.Foundation.Collections.IPropertySet: ...
    @winrt_commethod(12)
    def GetCurrentView(self) -> win32more.Windows.ApplicationModel.Core.CoreApplicationView: ...
    @winrt_commethod(13)
    def Run(self, viewSource: win32more.Windows.ApplicationModel.Core.IFrameworkViewSource) -> Void: ...
    @winrt_commethod(14)
    def RunWithActivationFactories(self, activationFactoryCallback: win32more.Windows.Foundation.IGetActivationFactory) -> Void: ...
    Id = property(get_Id, None)
    Properties = property(get_Properties, None)
    Suspending = event()
    Resuming = event()
class ICoreApplication2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Core.ICoreApplication2'
    _iid_ = Guid('{998681fb-1ab6-4b7f-be4a-9a0645224c04}')
    @winrt_commethod(6)
    def add_BackgroundActivated(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.ApplicationModel.Activation.BackgroundActivatedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_BackgroundActivated(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(8)
    def add_LeavingBackground(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.ApplicationModel.LeavingBackgroundEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_LeavingBackground(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def add_EnteredBackground(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.ApplicationModel.EnteredBackgroundEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_EnteredBackground(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(12)
    def EnablePrelaunch(self, value: Boolean) -> Void: ...
    BackgroundActivated = event()
    LeavingBackground = event()
    EnteredBackground = event()
class ICoreApplication3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Core.ICoreApplication3'
    _iid_ = Guid('{feec0d39-598b-4507-8a67-772632580a57}')
    @winrt_commethod(6)
    def RequestRestartAsync(self, launchArguments: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.Core.AppRestartFailureReason]: ...
    @winrt_commethod(7)
    def RequestRestartForUserAsync(self, user: win32more.Windows.System.User, launchArguments: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.Core.AppRestartFailureReason]: ...
class ICoreApplicationExit(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Core.ICoreApplicationExit'
    _iid_ = Guid('{cf86461d-261e-4b72-9acd-44ed2ace6a29}')
    @winrt_commethod(6)
    def Exit(self) -> Void: ...
    @winrt_commethod(7)
    def add_Exiting(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(8)
    def remove_Exiting(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    Exiting = event()
class ICoreApplicationUnhandledError(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Core.ICoreApplicationUnhandledError'
    _iid_ = Guid('{f0e24ab0-dd09-42e1-b0bc-e0e131f78d7e}')
    @winrt_commethod(6)
    def add_UnhandledErrorDetected(self, handler: win32more.Windows.Foundation.EventHandler[win32more.Windows.ApplicationModel.Core.UnhandledErrorDetectedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_UnhandledErrorDetected(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    UnhandledErrorDetected = event()
class ICoreApplicationUseCount(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Core.ICoreApplicationUseCount'
    _iid_ = Guid('{518dc408-c077-475b-809e-0bc0c57e4b74}')
    @winrt_commethod(6)
    def IncrementApplicationUseCount(self) -> Void: ...
    @winrt_commethod(7)
    def DecrementApplicationUseCount(self) -> Void: ...
class ICoreApplicationView(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Core.ICoreApplicationView'
    _iid_ = Guid('{638bb2db-451d-4661-b099-414f34ffb9f1}')
    @winrt_commethod(6)
    def get_CoreWindow(self) -> win32more.Windows.UI.Core.CoreWindow: ...
    @winrt_commethod(7)
    def add_Activated(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Core.CoreApplicationView, win32more.Windows.ApplicationModel.Activation.IActivatedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(8)
    def remove_Activated(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(9)
    def get_IsMain(self) -> Boolean: ...
    @winrt_commethod(10)
    def get_IsHosted(self) -> Boolean: ...
    CoreWindow = property(get_CoreWindow, None)
    IsHosted = property(get_IsHosted, None)
    IsMain = property(get_IsMain, None)
    Activated = event()
class ICoreApplicationView2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Core.ICoreApplicationView2'
    _iid_ = Guid('{68eb7adf-917f-48eb-9aeb-7de53e086ab1}')
    @winrt_commethod(6)
    def get_Dispatcher(self) -> win32more.Windows.UI.Core.CoreDispatcher: ...
    Dispatcher = property(get_Dispatcher, None)
class ICoreApplicationView3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Core.ICoreApplicationView3'
    _iid_ = Guid('{07ebe1b3-a4cf-4550-ab70-b07e85330bc8}')
    @winrt_commethod(6)
    def get_IsComponent(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_TitleBar(self) -> win32more.Windows.ApplicationModel.Core.CoreApplicationViewTitleBar: ...
    @winrt_commethod(8)
    def add_HostedViewClosing(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Core.CoreApplicationView, win32more.Windows.ApplicationModel.Core.HostedViewClosingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_HostedViewClosing(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    IsComponent = property(get_IsComponent, None)
    TitleBar = property(get_TitleBar, None)
    HostedViewClosing = event()
class ICoreApplicationView5(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Core.ICoreApplicationView5'
    _iid_ = Guid('{2bc095a8-8ef0-446d-9e60-3a3e0428c671}')
    @winrt_commethod(6)
    def get_Properties(self) -> win32more.Windows.Foundation.Collections.IPropertySet: ...
    Properties = property(get_Properties, None)
class ICoreApplicationView6(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Core.ICoreApplicationView6'
    _iid_ = Guid('{c119d49a-0679-49ba-803f-b79c5cf34cca}')
    @winrt_commethod(6)
    def get_DispatcherQueue(self) -> win32more.Windows.System.DispatcherQueue: ...
    DispatcherQueue = property(get_DispatcherQueue, None)
class ICoreApplicationViewTitleBar(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Core.ICoreApplicationViewTitleBar'
    _iid_ = Guid('{006d35e3-e1f1-431b-9508-29b96926ac53}')
    @winrt_commethod(6)
    def put_ExtendViewIntoTitleBar(self, value: Boolean) -> Void: ...
    @winrt_commethod(7)
    def get_ExtendViewIntoTitleBar(self) -> Boolean: ...
    @winrt_commethod(8)
    def get_SystemOverlayLeftInset(self) -> Double: ...
    @winrt_commethod(9)
    def get_SystemOverlayRightInset(self) -> Double: ...
    @winrt_commethod(10)
    def get_Height(self) -> Double: ...
    @winrt_commethod(11)
    def add_LayoutMetricsChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Core.CoreApplicationViewTitleBar, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(12)
    def remove_LayoutMetricsChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(13)
    def get_IsVisible(self) -> Boolean: ...
    @winrt_commethod(14)
    def add_IsVisibleChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.ApplicationModel.Core.CoreApplicationViewTitleBar, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(15)
    def remove_IsVisibleChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    ExtendViewIntoTitleBar = property(get_ExtendViewIntoTitleBar, put_ExtendViewIntoTitleBar)
    Height = property(get_Height, None)
    IsVisible = property(get_IsVisible, None)
    SystemOverlayLeftInset = property(get_SystemOverlayLeftInset, None)
    SystemOverlayRightInset = property(get_SystemOverlayRightInset, None)
    LayoutMetricsChanged = event()
    IsVisibleChanged = event()
class ICoreImmersiveApplication(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Core.ICoreImmersiveApplication'
    _iid_ = Guid('{1ada0e3e-e4a2-4123-b451-dc96bf800419}')
    @winrt_commethod(6)
    def get_Views(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.ApplicationModel.Core.CoreApplicationView]: ...
    @winrt_commethod(7)
    def CreateNewView(self, runtimeType: WinRT_String, entryPoint: WinRT_String) -> win32more.Windows.ApplicationModel.Core.CoreApplicationView: ...
    @winrt_commethod(8)
    def get_MainView(self) -> win32more.Windows.ApplicationModel.Core.CoreApplicationView: ...
    MainView = property(get_MainView, None)
    Views = property(get_Views, None)
class ICoreImmersiveApplication2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Core.ICoreImmersiveApplication2'
    _iid_ = Guid('{828e1e36-e9e3-4cfc-9b66-48b78ea9bb2c}')
    @winrt_commethod(6)
    def CreateNewViewFromMainView(self) -> win32more.Windows.ApplicationModel.Core.CoreApplicationView: ...
class ICoreImmersiveApplication3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Core.ICoreImmersiveApplication3'
    _iid_ = Guid('{34a05b2f-ee0d-41e5-8314-cf10c91bf0af}')
    @winrt_commethod(6)
    def CreateNewViewWithViewSource(self, viewSource: win32more.Windows.ApplicationModel.Core.IFrameworkViewSource) -> win32more.Windows.ApplicationModel.Core.CoreApplicationView: ...
class IFrameworkView(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Core.IFrameworkView'
    _iid_ = Guid('{faab5cd0-8924-45ac-ad0f-a08fae5d0324}')
    @winrt_commethod(6)
    def Initialize(self, applicationView: win32more.Windows.ApplicationModel.Core.CoreApplicationView) -> Void: ...
    @winrt_commethod(7)
    def SetWindow(self, window: win32more.Windows.UI.Core.CoreWindow) -> Void: ...
    @winrt_commethod(8)
    def Load(self, entryPoint: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def Run(self) -> Void: ...
    @winrt_commethod(10)
    def Uninitialize(self) -> Void: ...
class IFrameworkViewSource(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Core.IFrameworkViewSource'
    _iid_ = Guid('{cd770614-65c4-426c-9494-34fc43554862}')
    @winrt_commethod(6)
    def CreateView(self) -> win32more.Windows.ApplicationModel.Core.IFrameworkView: ...
class IHostedViewClosingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Core.IHostedViewClosingEventArgs'
    _iid_ = Guid('{d238943c-b24e-4790-acb5-3e4243c4ff87}')
    @winrt_commethod(6)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
class IUnhandledError(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Core.IUnhandledError'
    _iid_ = Guid('{9459b726-53b5-4686-9eaf-fa8162dc3980}')
    @winrt_commethod(6)
    def get_Handled(self) -> Boolean: ...
    @winrt_commethod(7)
    def Propagate(self) -> Void: ...
    Handled = property(get_Handled, None)
class IUnhandledErrorDetectedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Core.IUnhandledErrorDetectedEventArgs'
    _iid_ = Guid('{679ab78b-b336-4822-ac40-0d750f0b7a2b}')
    @winrt_commethod(6)
    def get_UnhandledError(self) -> win32more.Windows.ApplicationModel.Core.UnhandledError: ...
    UnhandledError = property(get_UnhandledError, None)
class UnhandledError(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Core.IUnhandledError
    _classid_ = 'Windows.ApplicationModel.Core.UnhandledError'
    @winrt_mixinmethod
    def get_Handled(self: win32more.Windows.ApplicationModel.Core.IUnhandledError) -> Boolean: ...
    @winrt_mixinmethod
    def Propagate(self: win32more.Windows.ApplicationModel.Core.IUnhandledError) -> Void: ...
    Handled = property(get_Handled, None)
class UnhandledErrorDetectedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Core.IUnhandledErrorDetectedEventArgs
    _classid_ = 'Windows.ApplicationModel.Core.UnhandledErrorDetectedEventArgs'
    @winrt_mixinmethod
    def get_UnhandledError(self: win32more.Windows.ApplicationModel.Core.IUnhandledErrorDetectedEventArgs) -> win32more.Windows.ApplicationModel.Core.UnhandledError: ...
    UnhandledError = property(get_UnhandledError, None)


make_ready(__name__)
